@@ -6,11 +6,11 @@
 #ifndef SPECTRUMPARSER_H
 #define SPECTRUMPARSER_H
 
-#include "libkdeedu_science_export.h"
+#include "science_export.h"
 
 #include <QFile>
-#include <QXmlDefaultHandler>
 #include <QXmlAttributes>
+#include <QXmlDefaultHandler>
 
 #include "spectrum.h"
 
@@ -28,14 +28,14 @@ public:
      * Constructor
      */
     SpectrumParser();
-    ~SpectrumParser();
-    bool startElement( const QString&, const QString &localName, const QString&, const QXmlAttributes &attrs ) override;
+    ~SpectrumParser() override;
+    bool startElement(const QString &, const QString &localName, const QString &, const QXmlAttributes &attrs) override;
 
-    bool endElement( const QString& namespaceURI, const QString &localName, const QString& qName ) override;
+    bool endElement(const QString &namespaceURI, const QString &localName, const QString &qName) override;
 
     bool characters(const QString &ch) override;
 
-    QList<Spectrum*> getSpectrums() const;
+    QList<Spectrum *> getSpectrums() const;
 
 private:
     QString currentElementID;
