@@ -22,10 +22,10 @@ class TableInfoWidget : public QWidget
 public:
     explicit TableInfoWidget(QWidget *parent);
 
-    ~TableInfoWidget() {}
+    ~TableInfoWidget() override = default;
 
 private:
-    QLabel *m_tableType;
+    QLabel *const m_tableType;
 
 public Q_SLOTS:
     void setTableType(int type);
